@@ -81,7 +81,11 @@ function configure_murano_rpc_backend() {
     # TODO(ruhe): get rid of this ugly workaround.
     inicomment $MURANO_CONF_FILE DEFAULT rpc_backend
 
-    iniset $MURANO_CONF_FILE rabbitmq host $RABBIT_HOST
+    if [[ $SERVICE_IP_VERSION == 6 ]]; then
+        iniset $MURANO_CONF_FILE rabbitmq host "$HOST_IPV6"
+    else
+        iniset $MURANO_CONF_FILE rabbitmq host "$HOST_IP"
+    fi
     iniset $MURANO_CONF_FILE rabbitmq login $RABBIT_USERID
     iniset $MURANO_CONF_FILE rabbitmq password $RABBIT_PASSWORD
 
@@ -404,7 +408,7 @@ function install_murano_pythonclient() {
 # start_murano() - Start running processes, including screen
 function start_murano() {
     if [ "$MURANO_USE_UWSGI" == "True" ]; then
-        run_process murano-api "$MURANO_BIN_DIR/uwsgi --ini $MURANO_UWSGI_CONF"
+        run_process murano-api "$(which uwsgi) --procname-prefix murano-api --ini $MURANO_UWSGI_CONF"
     else
         run_process murano-api "$MURANO_BIN_DIR/murano-api --config-file $MURANO_CONF_DIR/murano.conf"
     fi
@@ -418,9 +422,8 @@ function stop_murano() {
     if [ "$MURANO_USE_UWSGI" == "True" ]; then
         disable_apache_site murano-api
         restart_apache_server
-    else
-        stop_process murano-api
     fi
+    stop_process murano-api
     stop_process murano-engine
 }
 
