@@ -21,7 +21,7 @@ from oslo_config import cfg
 from oslo_log import log
 from webob import exc
 
-from murano.common.i18n import _, _LW
+from murano.common.i18n import _
 from murano.common import wsgi
 
 CONF = cfg.CONF
@@ -44,7 +44,7 @@ class ExternalContextMiddleware(wsgi.Middleware):
         elif auth_url.endswith('v3'):
             pass
         else:
-            LOG.warning(_LW('Wrong format for service broker auth url'))
+            LOG.warning('Wrong format for service broker auth url')
 
         kwargs = {'auth_url': auth_url,
                   'username': user,
@@ -91,7 +91,7 @@ class ExternalContextMiddleware(wsgi.Middleware):
         try:
             credentials = base64.b64decode(
                 req.headers['Authorization'].split(' ')[1])
-            user, password = credentials.split(':', 2)
+            user, password = credentials.decode('utf-8').split(':', 2)
             req.headers['X-Auth-Token'] = self.get_keystone_token(user,
                                                                   password)
             req.endpoints = self.get_endpoints()
