@@ -23,18 +23,16 @@ from keystoneclient import service_catalog
 from oslo_config import cfg
 from oslo_db import exception as db_exc
 from oslo_log import log as logging
-from oslo_log import versionutils
-import six
 from webob import exc
 
 import murano.api.v1
 from murano.api.v1 import validation_schemas
 from murano.common import exceptions
+from murano.common.i18n import _
 from murano.common import policy
 import murano.common.utils as murano_utils
 from murano.common import wsgi
 from murano.db.catalog import api as db_api
-from murano.common.i18n import _, _LW
 from murano.packages import exceptions as pkg_exc
 from murano.packages import load_utils
 from muranoclient.glance import client as glare_client
@@ -64,8 +62,8 @@ def _get_filters(query_params):
     for param_pair in query_params:
         k, v = param_pair
         if k not in SUPPORTED_PARAMS:
-            LOG.warning(_LW("Search by parameter '{name}' "
-                            "is not supported. Skipping it.").format(name=k))
+            LOG.warning("Search by parameter '{name}' "
+                        "is not supported. Skipping it.".format(name=k))
             continue
 
         if k in LIST_PARAMS:
@@ -74,10 +72,10 @@ def _get_filters(query_params):
                 try:
                     filters[k] = murano_utils.split_for_quotes(in_value)
                 except ValueError as err:
-                    LOG.warning(_LW("Search by parameter '{name}' "
-                                    "caused an {message} error."
-                                    "Skipping it.").format(name=k,
-                                                           message=err))
+                    LOG.warning("Search by parameter '{name}' "
+                                "caused an {message} error."
+                                "Skipping it.".format(name=k,
+                                                      message=err))
             else:
                 filters.setdefault(k, []).append(v)
         else:
@@ -86,8 +84,8 @@ def _get_filters(query_params):
         for i in order_by[:]:
             if ORDER_VALUES and i not in ORDER_VALUES:
                 filters['order_by'].remove(i)
-                LOG.warning(_LW("Value of 'order_by' parameter is not valid. "
-                                "Allowed values are: {values}. Skipping it.")
+                LOG.warning("Value of 'order_by' parameter is not valid. "
+                            "Allowed values are: {values}. Skipping it."
                             .format(values=", ".join(ORDER_VALUES)))
     return filters
 
@@ -139,21 +137,21 @@ class Controller(object):
     """WSGI controller for application catalog resource in Murano v1 API."""
 
     def _validate_limit(self, value):
-            if value is None:
-                return
-            try:
-                value = int(value)
-            except ValueError:
-                msg = _("Limit param must be an integer")
-                LOG.error(msg)
-                raise exc.HTTPBadRequest(explanation=msg)
+        if value is None:
+            return
+        try:
+            value = int(value)
+        except ValueError:
+            msg = _("Limit param must be an integer")
+            LOG.error(msg)
+            raise exc.HTTPBadRequest(explanation=msg)
 
-            if value <= 0:
-                msg = _("Limit param must be positive")
-                LOG.error(msg)
-                raise exc.HTTPBadRequest(explanation=msg)
+        if value <= 0:
+            msg = _("Limit param must be positive")
+            LOG.error(msg)
+            raise exc.HTTPBadRequest(explanation=msg)
 
-            return value
+        return value
 
     def update(self, req, body, package_id):
         """List of allowed changes
@@ -262,9 +260,13 @@ class Controller(object):
                     tempf.name, target_dir=None,
                     drop_dir=True) as pkg_to_upload:
                 # extend dictionary for update db
-                for k, v in six.iteritems(PKG_PARAMS_MAP):
+                for k, v in PKG_PARAMS_MAP.items():
                     if hasattr(pkg_to_upload, k):
-                        package_meta[v] = getattr(pkg_to_upload, k)
+                        if k == "tags" and package_meta.get(k):
+                            package_meta[v] = list(set(
+                                package_meta[v] + getattr(pkg_to_upload, k)))
+                        else:
+                            package_meta[v] = getattr(pkg_to_upload, k)
                 if len(package_meta['name']) > 80:
                     msg = _('Package name should be 80 characters maximum')
                     LOG.error(msg)
@@ -338,13 +340,6 @@ class Controller(object):
         category = db_api.category_get(category_id, packages=True)
         return category.to_dict()
 
-    @versionutils.deprecated(as_of=versionutils.deprecated.LIBERTY,
-                             in_favor_of='categories.list()')
-    def show_categories(self, req):
-        policy.check("get_category", req.context)
-        categories = db_api.categories_list()
-        return {'categories': [category.name for category in categories]}
-
     def list_categories(self, req):
         """List all categories
 
@@ -434,11 +429,12 @@ class Controller(object):
         url = glare_settings.url
         if not url:
             url = self._get_glare_url(request)
+        # TODO(gyurco): use auth_utils.get_session_client_parameters
         client = glare_client.Client(
             endpoint=url, token=token, insecure=glare_settings.insecure,
-            key_file=glare_settings.key_file or None,
-            ca_file=glare_settings.ca_file or None,
-            cert_file=glare_settings.cert_file or None,
+            key_file=glare_settings.keyfile or None,
+            ca_file=glare_settings.cafile or None,
+            cert_file=glare_settings.certfile or None,
             type_name='murano',
             type_version=1)
         return client
