@@ -17,11 +17,9 @@ import uuid
 
 from oslo_config import cfg
 from oslo_log import log as logging
-import retrying
-import six
+import tenacity
 from webob import response
 
-from murano.common.i18n import _LI, _LW
 from murano.common import auth_utils  # noqa
 from murano.common import wsgi
 from murano.db.services import cf_connections as db_cf
@@ -111,9 +109,9 @@ class Controller(object):
         except AttributeError:
             tenant = req.headers['X-Project-Id']
             db_cf.set_tenant_for_org(org_guid, tenant)
-            LOG.info(_LI("Cloud Foundry {org_id} mapped to tenant "
-                         "{tenant_name}").format(org_id=org_guid,
-                                                 tenant_name=tenant))
+            LOG.info("Cloud Foundry {org_id} mapped to tenant "
+                     "{tenant_name}".format(org_id=org_guid,
+                                            tenant_name=tenant))
 
         token = req.headers['X-Auth-Token']
         m_cli = _get_muranoclient(token, req)
@@ -133,19 +131,19 @@ class Controller(object):
             try:
                 env = m_cli.environments.get(environment_id)
             except exceptions.HTTPNotFound:
-                msg = (_LI("Can not find environment_id {environment_id}, "
-                           "will create a new one."
-                           ).format(environment_id=environment_id))
+                msg = ("Can not find environment_id {environment_id}, "
+                       "will create a new one."
+                       .format(environment_id=environment_id))
                 LOG.info(msg)
                 env = {}
             if not env:
-                log_msg = (_LI("Cloud Foundry {space_id} remapped to "
-                               "{environment_id}"))
+                log_msg = ("Cloud Foundry {space_id} remapped to "
+                           "{environment_id}")
                 environment_id = _set_new_environment_for_space(
                     space_guid, log_msg)
         except AttributeError:
-            log_msg = (_LI("Cloud Foundry {space_id} mapped to "
-                           "{environment_id}"))
+            log_msg = ("Cloud Foundry {space_id} mapped to "
+                       "{environment_id}")
             environment_id = _set_new_environment_for_space(
                 space_guid, log_msg)
 
@@ -162,13 +160,13 @@ class Controller(object):
         # necessary in our scenario
         if '?' in parameters.keys():
             parameters.pop('?', None)
-            LOG.warning(_LW("Incorrect input parameters. Package related "
-                            "parameters shouldn't be passed through Cloud "
-                            "Foundry"))
+            LOG.warning("Incorrect input parameters. Package related "
+                        "parameters shouldn't be passed through Cloud "
+                        "Foundry")
         params = [parameters]
         while params:
             a = params.pop()
-            for k, v in six.iteritems(a):
+            for k, v in a.items():
                 if isinstance(v, dict):
                     params.append(v)
                     if k == '?':
@@ -216,7 +214,7 @@ class Controller(object):
         LOG.debug('Got service {0}'.format(service))
 
         # NOTE(starodubcevna): Here we need to find an action which will return
-        # us needed credentials. By default we will looking for getCredentials
+        # us needed credentials. By default we will look for getCredentials
         # action.
         result = {}
         try:
@@ -224,11 +222,11 @@ class Controller(object):
             for action_id in list(actions):
                 if 'getCredentials' in action_id:
 
-                    @retrying.retry(retry_on_exception=lambda e: isinstance(e,
-                                    TypeError),
-                                    wait_random_min=1000,
-                                    wait_random_max=10000,
-                                    stop_max_delay=30000)
+                    @tenacity.retry(
+                        retry=tenacity.retry_if_exception_type(TypeError),
+                        wait=tenacity.wait_random(min=1, max=10),
+                        stop=tenacity.stop_after_delay(30),
+                        reraise=True)
                     def _get_creds(client, task_id, environment_id):
                         result = m_cli.actions.get_result(environment_id,
                                                           task_id)['result']
@@ -238,13 +236,13 @@ class Controller(object):
                     result = _get_creds(m_cli, task_id, environment_id)
 
             if not result:
-                LOG.warning(_LW("This application doesn't have action "
-                                "getCredentials"))
+                LOG.warning("This application doesn't have action "
+                            "getCredentials")
                 return response.Response(status=500)
         except KeyError:
             # NOTE(starodubcevna): In CF service broker API spec return
             # code for failed bind is not present, so we will return 500.
-            LOG.warning(_LW("This application doesn't have actions at all"))
+            LOG.warning("This application doesn't have actions at all")
             return response.Response(status=500)
 
         if 'credentials' in list(result):
@@ -269,7 +267,8 @@ class Controller(object):
         # NOTE(freerunner): Prevent code 500 if requested environment
         # already doesn't exist.
         if not service:
-            LOG.warning(_LW('Requested service for instance {} is not found'))
+            LOG.warning('Requested service for instance {0} is not '
+                        'found'.format(instance_id))
             body = {}
             resp = response.Response(status=410, json_body=body)
             return resp
@@ -280,6 +279,8 @@ class Controller(object):
         # NOTE(starodubcevna): we can track only environment status. it's
         # murano API limitation.
         m_environment = m_cli.environments.get(env_id)
+        body = {'state': 'unknown', 'description': 'operation unknown'}
+        resp = response.Response(status=500, json_body=body)
         if m_environment.status == 'ready':
             body = {'state': 'succeeded',
                     'description': 'operation succeed'}
@@ -299,12 +300,13 @@ class Controller(object):
 def _get_muranoclient(token_id, req):
 
     artifacts_client = None
-    if CONF.cfapi.packages_service in ['glance', 'glare']:
+    if CONF.engine.packages_service in ['glance', 'glare']:
         artifacts_client = _get_glareclient(token_id, req)
 
     murano_url = CONF.murano.url or req.endpoints.get('murano')
     if not murano_url:
-        LOG.error('No murano url is specified and no "application-catalog" '
+        LOG.error('No murano url is specified and no '
+                  '"application-catalog" '
                   'service is registered in keystone.')
 
     return muranoclient.Client(1, murano_url, token=token_id,
@@ -318,13 +320,13 @@ def _get_glareclient(token_id, req):
     if not url:
         LOG.error('No glare url is specified and no "artifact" '
                   'service is registered in keystone.')
-
+    # TODO(gyurco): use auth_utils.get_session_client_parameters
     return glare_client.Client(
         endpoint=url, token=token_id,
         insecure=glare_settings.insecure,
-        key_file=glare_settings.key_file or None,
-        ca_file=glare_settings.ca_file or None,
-        cert_file=glare_settings.cert_file or None,
+        key_file=glare_settings.keyfile or None,
+        ca_file=glare_settings.cafile or None,
+        cert_file=glare_settings.certfile or None,
         type_name='murano',
         type_version=1)
 
