@@ -12,25 +12,22 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
 from oslo_db import api as oslo_db_api
 from oslo_db import exception as db_exceptions
 from oslo_db.sqlalchemy import utils
 from oslo_log import log as logging
-import six
+import re
 import sqlalchemy as sa
 from sqlalchemy import or_
 from sqlalchemy.orm import attributes
 # TODO(ruhe) use exception declared in openstack/common/db
 from webob import exc
 
+from murano.common.i18n import _
 from murano.db import models
 from murano.db import session as db_session
-from murano.common.i18n import _, _LW
 
 
-CONF = cfg.CONF
-
 SEARCH_MAPPING = {'fqn': 'fully_qualified_name',
                   'name': 'name',
                   'created': 'created'
@@ -71,6 +68,7 @@ def _authorize_package(package, context, allow_public=False):
 
 def package_get(package_id, context):
     """Return package details
+
        :param package_id: ID or name of a package, string
        :returns: detailed information about package, dict
     """
@@ -112,6 +110,7 @@ def _existing_tag(tag_name, session=None):
 
 def _get_tags(tag_names, session=None):
     """Return existing tags object or create new ones
+
        :param tag_names: name of tags to associate with package, list
        :returns: list of Tag objects to associate with package, list
     """
@@ -128,7 +127,7 @@ def _get_tags(tag_names, session=None):
             tag_obj = _existing_tag(tag_name, session)
             if not tag_obj:
                 try:
-                    # Start a new SAVEPOINT transaction. If it fails only
+                    # Start a new SAVEPOINT transaction. If it fails
                     # only the savepoint will be roll backed, not the
                     # whole transaction.
                     with session.begin(nested=True):
@@ -189,9 +188,8 @@ def _do_add(package, change):
         try:
             getattr(package, path).append(item)
         except AssertionError:
-            LOG.warning(_LW('One of the specified {path} is already associated'
-                            ' with a package. Doing nothing.').format(
-                                path=path))
+            LOG.warning('One of the specified {path} is already associated'
+                        ' with a package. Doing nothing.'.format(path=path))
     return package
 
 
@@ -219,6 +217,7 @@ def _do_remove(package, change):
 
 def _get_packages_for_category(session, category_id):
     """Return detailed list of packages, belonging to the provided category
+
     :param session:
     :param category_id:
     :return: list of dictionaries, containing id, name and package fqn
@@ -241,6 +240,7 @@ def _get_packages_for_category(session, category_id):
 @oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
 def package_update(pkg_id_or_name, changes, context):
     """Update package information
+
        :param changes: parameters to update
        :returns: detailed information about new package, dict
     """
@@ -275,6 +275,7 @@ def package_update(pkg_id_or_name, changes, context):
 def package_search(filters, context, manage_public=False,
                    limit=None, catalog=False):
     """Search packages with different filters
+
       Catalog param controls the base query creation. Catalog queries
       only search packages a user can deploy. Non-catalog queries searches
       packages a user can edit.
@@ -338,26 +339,43 @@ def package_search(filters, context, manage_public=False,
         fk_fields = {'categories': 'Category',
                      'tags': 'Tag',
                      'class_definitions': 'Class'}
-        conditions = []
+        # the default search order
+        fields = ['name',
+                  'fully_qualified_name',
+                  'description',
+                  'categories',
+                  'tags',
+                  'class_definitions',
+                  'author']
+        # split to searching words
+        key_words = re.split(';|,', filters['search'])
 
-        for attr in dir(pkg):
+        conditions = []
+        order_cases = []
+        sorted_fields = fields + list(set(dir(pkg)).difference(set(fields)))
+        for index in range(0, len(sorted_fields)):
+            attr = sorted_fields[index]
             if attr.startswith('_'):
                 continue
-            if isinstance(getattr(pkg, attr),
-                          attributes.InstrumentedAttribute):
-                search_str = filters['search']
-                for delim in ',;':
-                    search_str = search_str.replace(delim, ' ')
-                for key_word in search_str.split():
-                    _word = u'%{value}%'.format(value=key_word)
-                    if attr in fk_fields.keys():
-                        condition = getattr(pkg, attr).any(
-                            getattr(models, fk_fields[attr]).name.like(_word))
-                        conditions.append(condition)
-                    elif isinstance(getattr(pkg, attr)
-                                    .property.columns[0].type, sa.String):
-                        conditions.append(getattr(pkg, attr).like(_word))
-        query = query.filter(or_(*conditions))
+            if not isinstance(getattr(pkg, attr),
+                              attributes.InstrumentedAttribute):
+                continue
+            priority = min(index, len(fields))
+            for key_word in key_words:
+                _word = u'%{value}%'.format(value=key_word)
+                if attr in fk_fields.keys():
+                    condition = getattr(pkg, attr).any(
+                        getattr(models, fk_fields[attr]).name.like(_word))
+                    conditions.append(condition)
+                    order_cases.append((condition, priority))
+                elif isinstance(getattr(pkg, attr)
+                                .property.columns[0].type, sa.String):
+                    condition = getattr(pkg, attr).like(_word)
+                    conditions.append(condition)
+                    order_cases.append((condition, priority))
+
+        order_expression = sa.case(order_cases).label("tmp_weight_uuid")
+        query = query.filter(or_(*conditions)).order_by(order_expression.asc())
 
     sort_keys = [SEARCH_MAPPING[sort_key] for sort_key in
                  filters.get('order_by', ['name'])]
@@ -377,6 +395,7 @@ def package_search(filters, context, manage_public=False,
 @oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
 def package_upload(values, tenant_id):
     """Upload a package with new application
+
        :param values: parameters describing the new package
        :returns: detailed information about new package, dict
     """
@@ -400,7 +419,7 @@ def package_upload(values, tenant_id):
             _check_for_public_packages_with_fqn(
                 session,
                 values.get('fully_qualified_name'))
-        for attr, func in six.iteritems(composite_attr_to_func):
+        for attr, func in composite_attr_to_func.items():
             if values.get(attr):
                 result = func(values[attr], session)
                 setattr(package, attr, result)
@@ -436,6 +455,7 @@ def package_delete(package_id, context):
 
 def category_get(category_id, session=None, packages=False):
     """Return category details
+
        :param category_id: ID of a category, string
        :returns: detailed information about category, dict
     """
