@@ -16,7 +16,6 @@ import semantic_version
 
 
 EXPRESSION_MEMORY_QUOTA = 512 * 1024
-ITERATORS_LIMIT = 2000
 
 CTX_ACTIONS_ONLY = '?actionsOnly'
 CTX_ALLOW_PROPERTY_WRITES = '$?allowPropertyWrites'
@@ -59,3 +58,4 @@ RUNTIME_VERSION_1_1 = semantic_version.Version('1.1.0')
 RUNTIME_VERSION_1_2 = semantic_version.Version('1.2.0')
 RUNTIME_VERSION_1_3 = semantic_version.Version('1.3.0')
 RUNTIME_VERSION_1_4 = semantic_version.Version('1.4.0')
+RUNTIME_VERSION_1_5 = semantic_version.Version('1.5.0')
