@@ -12,8 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
-import six
 from yaql import utils
 
 from murano.dsl import dsl
@@ -48,7 +46,7 @@ def _serialize_object(root_object, designer_attributes, allow_refs,
     obj = root_object
     if isinstance(obj, dsl.MuranoObjectInterface):
         obj = obj.object
-    parent = obj.owner if isinstance(obj,  dsl_types.MuranoObject) else None
+    parent = obj.owner if isinstance(obj, dsl_types.MuranoObject) else None
     while True:
         obj, need_another_pass = _pass12_serialize(
             obj, parent, serialized_objects, designer_attributes, executor,
@@ -127,8 +125,7 @@ def _pass12_serialize(value, parent, serialized_objects,
                       with_destruction_dependencies):
     if isinstance(value, dsl.MuranoObjectInterface):
         value = value.object
-    if isinstance(value, (six.string_types,
-                          int, float, bool)) or value is None:
+    if isinstance(value, (str, int, float, bool)) or value is None:
         return value, False
     if isinstance(value, dsl_types.MuranoObject):
         if value.owner is not parent or value.object_id in serialized_objects:
@@ -255,8 +252,8 @@ def collect_objects(root_object):
                 for t in rec(value):
                     yield t
         elif isinstance(obj, dsl_types.MuranoObjectInterface):
-                for t in rec(obj.object):
-                    yield t
+            for t in rec(obj.object):
+                yield t
         elif isinstance(obj, dsl_types.MuranoObject) and obj not in visited:
             visited.add(obj)
             yield obj
