@@ -29,10 +29,10 @@ import muranoclient.v1.client as muranoclient
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_log import versionutils
-import six
+from oslo_utils import fileutils
 
 from murano.common import auth_utils
-from murano.common.i18n import _LE, _LI, _LW
+from murano.common import utils
 from murano.dsl import constants
 from murano.dsl import exceptions
 from murano.dsl import helpers
@@ -84,27 +84,25 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
                     service_type='artifact',
                     interface=glare_settings.endpoint_type,
                     region_name=CONF.home_region)
-
+            # TODO(gyurco): use auth_utils.get_session_client_parameters
             self._glare_client = glare_client.Client(
                 endpoint=url, token=token,
                 insecure=glare_settings.insecure,
-                key_file=glare_settings.key_file or None,
-                ca_file=glare_settings.ca_file or None,
-                cert_file=glare_settings.cert_file or None,
+                key_file=glare_settings.keyfile or None,
+                ca_file=glare_settings.cafile or None,
+                cert_file=glare_settings.certfile or None,
                 type_name='murano',
                 type_version=1)
         return self._glare_client
 
     @property
     def client(self):
-        murano_settings = CONF.murano
         last_glare_client = self._glare_client
         if CONF.engine.packages_service in ['glance', 'glare']:
             if CONF.engine.packages_service == 'glance':
                 versionutils.report_deprecated_feature(
-                    LOG,
-                    _LW("'glance' packages_service option has been renamed "
-                        "to 'glare', please update your configuration"))
+                    LOG, "'glance' packages_service option has been renamed "
+                         "to 'glare', please update your configuration")
             artifacts_client = self._get_glare_client()
         else:
             artifacts_client = None
@@ -114,7 +112,7 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
             parameters = auth_utils.get_session_client_parameters(
                 service_type='application-catalog',
                 execution_session=self._execution_session,
-                conf=murano_settings
+                conf='murano'
             )
             self._murano_client = muranoclient.Client(
                 artifacts_client=artifacts_client, **parameters)
@@ -123,7 +121,7 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
     def load_class_package(self, class_name, version_spec):
         packages = self._class_cache.get(class_name)
         if packages:
-            version = version_spec.select(six.iterkeys(packages))
+            version = version_spec.select(packages.keys())
             if version:
                 return packages[version]
 
@@ -135,9 +133,9 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
             self._lock_usage(package_definition)
         except LookupError:
             exc_info = sys.exc_info()
-            six.reraise(exceptions.NoPackageForClassFound,
-                        exceptions.NoPackageForClassFound(class_name),
-                        exc_info[2])
+            utils.reraise(exceptions.NoPackageForClassFound,
+                          exceptions.NoPackageForClassFound(class_name),
+                          exc_info[2])
         return self._to_dsl_package(
             self._get_package_by_definition(package_definition))
 
@@ -149,7 +147,7 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
 
         packages = self._package_cache.get(package_name)
         if packages:
-            version = version_spec.select(six.iterkeys(packages))
+            version = version_spec.select(packages.keys())
             if version:
                 return packages[version]
 
@@ -161,8 +159,9 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
             self._lock_usage(package_definition)
         except LookupError:
             exc_info = sys.exc_info()
-            six.reraise(exceptions.NoPackageFound(package_name),
-                        None, exc_info[2])
+            utils.reraise(exceptions.NoPackageFound,
+                          exceptions.NoPackageFound(package_name),
+                          exc_info[2])
         else:
             package = self._get_package_by_definition(package_definition)
             self._fixations[package_name].add(package.version)
@@ -189,7 +188,7 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
                                                      uuid.uuid4().hex))
 
         if not os.path.isdir(directory):
-            m_utils.ensure_tree(directory)
+            fileutils.ensure_tree(directory)
 
         LOG.debug('Cache for package loader is located at: {dir}'.format(
             dir=directory))
@@ -239,11 +238,10 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
             try:
                 return load_utils.load_from_dir(package_directory)
             except pkg_exc.PackageLoadError:
-                LOG.exception(
-                    _LE('Unable to load package from cache. Clean-up.'))
+                LOG.exception('Unable to load package from cache. Clean-up.')
                 shutil.rmtree(package_directory, ignore_errors=True)
 
-        # the package is not yet in cache, let's try and download it.
+        # the package is not yet in cache, let's try to download it.
         download_lock_path = os.path.join(
             self._cache_directory, '{}_download.lock'.format(package_id))
         download_ipc_lock = m_utils.ExclusiveInterProcessLock(
@@ -258,8 +256,7 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
                 try:
                     return load_utils.load_from_dir(package_directory)
                 except pkg_exc.PackageLoadError:
-                    LOG.error(
-                        _LE('Unable to load package from cache. Clean-up.'))
+                    LOG.error('Unable to load package from cache. Clean-up.')
                     shutil.rmtree(package_directory, ignore_errors=True)
 
             # attempt the download itself
@@ -272,9 +269,9 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
                     package_id, str(e)
                 )
                 exc_info = sys.exc_info()
-                six.reraise(pkg_exc.PackageLoadError,
-                            pkg_exc.PackageLoadError(msg),
-                            exc_info[2])
+                utils.reraise(pkg_exc.PackageLoadError,
+                              pkg_exc.PackageLoadError(msg),
+                              exc_info[2])
             package_file = None
             try:
                 with tempfile.NamedTemporaryFile(delete=False) as package_file:
@@ -284,9 +281,10 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
                         package_file.name,
                         target_dir=package_directory,
                         drop_dir=False) as app_package:
-                    LOG.info(_LI(
-                        "Successfully downloaded and unpacked package {} {}")
-                        .format(package_def.fully_qualified_name, package_id))
+                    LOG.info(
+                        "Successfully downloaded and unpacked "
+                        "package {} {}".format(
+                            package_def.fully_qualified_name, package_id))
                     self._downloaded.append(app_package)
 
                     self.try_cleanup_cache(
@@ -296,9 +294,9 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
             except IOError:
                 msg = 'Unable to extract package data for %s' % package_id
                 exc_info = sys.exc_info()
-                six.reraise(pkg_exc.PackageLoadError,
-                            pkg_exc.PackageLoadError(msg),
-                            exc_info[2])
+                utils.reraise(pkg_exc.PackageLoadError,
+                              pkg_exc.PackageLoadError(msg),
+                              exc_info[2])
             finally:
                 try:
                     if package_file:
@@ -363,9 +361,8 @@ class ApiPackageLoader(package_loader.MuranoPackageLoader):
                         try:
                             os.remove(lock_path)
                         except OSError:
-                            LOG.warning(
-                                _LW("Couldn't delete lock file: "
-                                    "{}").format(lock_path))
+                            LOG.warning("Couldn't delete lock file: "
+                                        "{}".format(lock_path))
             except RuntimeError:
                 # couldn't upgrade read lock to write-lock. go on.
                 continue
@@ -468,10 +465,10 @@ class DirectoryPackageLoader(package_loader.MuranoPackageLoader):
                     system_objects.register(dsl_package)
                 self.register_package(dsl_package)
             except pkg_exc.PackageLoadError:
-                LOG.info(_LI('Unable to load package from path: {0}').format(
+                LOG.info('Unable to load package from path: {0}'.format(
                     folder))
                 continue
-            LOG.info(_LI('Loaded package from path {0}').format(folder))
+            LOG.info('Loaded package from path {0}'.format(folder))
 
     def import_fixation_table(self, fixations):
         self._fixations = deserialize_package_fixations(fixations)
@@ -486,7 +483,7 @@ class DirectoryPackageLoader(package_loader.MuranoPackageLoader):
         packages = self._packages_by_class.get(class_name)
         if not packages:
             raise exceptions.NoPackageForClassFound(class_name)
-        version = version_spec.select(six.iterkeys(packages))
+        version = version_spec.select(packages.keys())
         if not version:
             raise exceptions.NoPackageForClassFound(class_name)
         return packages[version]
@@ -499,7 +496,7 @@ class DirectoryPackageLoader(package_loader.MuranoPackageLoader):
         packages = self._packages_by_name.get(package_name)
         if not packages:
             raise exceptions.NoPackageFound(package_name)
-        version = version_spec.select(six.iterkeys(packages))
+        version = version_spec.select(packages.keys())
         if not version:
             raise exceptions.NoPackageFound(package_name)
         self._fixations[package_name].add(version)
@@ -515,8 +512,8 @@ class DirectoryPackageLoader(package_loader.MuranoPackageLoader):
 
     @property
     def packages(self):
-        for package_versions in six.itervalues(self._packages_by_name):
-            for package in six.itervalues(package_versions):
+        for package_versions in self._packages_by_name.values():
+            for package in package_versions.values():
                 yield package
 
     @staticmethod
@@ -584,7 +581,7 @@ class CombinedPackageLoader(package_loader.MuranoPackageLoader):
         for loader in self.directory_loaders:
             fixations = deserialize_package_fixations(
                 loader.export_fixation_table())
-            for key, value in six.iteritems(fixations):
+            for key, value in fixations.items():
                 result[key].update(value)
         return serialize_package_fixations(result)
 
@@ -627,7 +624,7 @@ def _with_to_generator(context_obj):
 
 def deserialize_package_fixations(fixations):
     result = collections.defaultdict(set)
-    for name, versions in six.iteritems(fixations):
+    for name, versions in fixations.items():
         for version in versions:
             result[name].add(helpers.parse_version(version))
     return result
@@ -636,5 +633,5 @@ def deserialize_package_fixations(fixations):
 def serialize_package_fixations(fixations):
     return {
         name: list(str(v) for v in versions)
-        for name, versions in six.iteritems(fixations)
+        for name, versions in fixations.items()
     }
