@@ -19,12 +19,12 @@ from netaddr.strategy import ipv4
 import neutronclient.v2_0.client as nclient
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_utils import netutils
 from oslo_utils import uuidutils
-import retrying
+import tenacity
 
 from murano.common import auth_utils
 from murano.common import exceptions as exc
-from murano.common.i18n import _LI
 from murano.dsl import dsl
 from murano.dsl import helpers
 from murano.dsl import session_local_storage
@@ -46,9 +46,8 @@ class NetworkExplorer(object):
     @staticmethod
     @session_local_storage.execution_session_memoize
     def _get_client(region_name):
-        neutron_settings = CONF.neutron
         return nclient.Client(**auth_utils.get_session_client_parameters(
-            service_type='network', region=region_name, conf=neutron_settings
+            service_type='network', region=region_name, conf='neutron'
         ))
 
     @property
@@ -60,10 +59,11 @@ class NetworkExplorer(object):
     # NOTE(starodubcevna): to avoid simultaneous router requests we use retry
     # decorator with random delay 1-10 seconds between attempts and maximum
     # delay time 30 seconds.
-    @retrying.retry(retry_on_exception=lambda e: isinstance(e,
-                    exc.RouterInfoException),
-                    wait_random_min=1000, wait_random_max=10000,
-                    stop_max_delay=30000)
+    @tenacity.retry(
+        retry=tenacity.retry_if_exception_type(exc.RouterInfoException),
+        stop=tenacity.stop_after_delay(30),
+        wait=tenacity.wait_random(min=1, max=10),
+        reraise=True)
     def get_default_router(self):
         router_name = self._settings.router_name
 
@@ -97,7 +97,7 @@ class NetworkExplorer(object):
                 }
                 router = self._client.create_router(
                     body=body_data).get('router')
-                LOG.info(_LI('Created router: {id}').format(id=router['id']))
+                LOG.info('Created router: {id}'.format(id=router['id']))
                 return router['id']
             else:
                 raise KeyError('Router %s was not found' % router_name)
@@ -108,7 +108,7 @@ class NetworkExplorer(object):
             router_id = routers[0]['id']
         return router_id
 
-    def get_available_cidr(self, router_id, net_id):
+    def get_available_cidr(self, router_id, net_id, ip_version=4):
         """Uses hash of network IDs to minimize the collisions
 
         Different nets will attempt to pick different cidrs out of available
@@ -118,6 +118,11 @@ class NetworkExplorer(object):
         taken_cidrs = self._get_cidrs_taken_by_router(router_id)
         id_hash = hash(net_id)
         num_fails = 0
+        available_ipv6_cidrs = []
+        if ip_version == 6:
+            for cidr in self._available_cidrs:
+                available_ipv6_cidrs.append(cidr.ipv6())
+            self._available_cidrs = available_ipv6_cidrs
         while num_fails < len(self._available_cidrs):
             cidr = self._available_cidrs[
                 (id_hash + num_fails) % len(self._available_cidrs)]
@@ -128,8 +133,18 @@ class NetworkExplorer(object):
                 return str(cidr)
         return None
 
-    def get_default_dns(self):
-        return self._settings.default_dns
+    def get_default_dns(self, ip_version=4):
+        dns_list = self._settings.default_dns
+        valid_dns = []
+        for ip in dns_list:
+            if ip_version == 6 and netutils.is_valid_ipv6(ip):
+                valid_dns.append(ip)
+            elif ip_version == 4 and netutils.is_valid_ipv4(ip):
+                valid_dns.append(ip)
+            else:
+                LOG.warning('{0} is not a vaild IPV{1} address, '
+                            'ingore...'.format(ip, ip_version))
+        return valid_dns
 
     def get_external_network_id_for_router(self, router_id):
         router = self._client.show_router(router_id).get('router')
@@ -150,7 +165,7 @@ class NetworkExplorer(object):
         # For each router this network is connected to
         # check if the router has external_gateway set
         for router_port in router_ports:
-            ext_net_id = self.getExternalNetworkIdForRouter(
+            ext_net_id = self.get_external_network_id_for_router(
                 router_port.get('device_id'))
             if ext_net_id:
                 return ext_net_id
