@@ -12,19 +12,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
 from murano.dsl import helpers
 
 
 class Object(object):
-    def __init__(self, __name, __id=None, **kwargs):
+    def __init__(self, __name, __id=None, class_version=None, **kwargs):
         self.data = {
             '?': {
                 'type': __name,
                 'id': __id or helpers.generate_id()
             }
         }
+        if class_version is not None:
+            self.data['?']['classVersion'] = class_version
         self.data.update(kwargs)
 
     @property
@@ -69,7 +69,7 @@ class Attribute(object):
 
 class Ref(object):
     def __init__(self, obj):
-        if isinstance(obj, six.string_types):
+        if isinstance(obj, str):
             self._id = obj
         else:
             self._id = obj.id
