@@ -12,14 +12,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
 import sys
 
-import six
-
+from murano.common import utils
 from murano.dsl import context_manager
 from murano.dsl import dsl
 from murano.dsl import dsl_exception
+from murano.dsl import dsl_types
 from murano.dsl import executor
 from murano.dsl import helpers
 from murano.dsl import murano_object
@@ -40,7 +39,7 @@ class TestContextManager(context_manager.ContextManager):
         context = helpers.link_contexts(
             root_context, yaql_functions.get_context(runtime_version))
         context = context.create_child_context()
-        for name, func in six.iteritems(self.__functions):
+        for name, func in self.__functions.items():
             context.register_function(func, name)
         return context
 
@@ -49,27 +48,32 @@ class Runner(object):
     class DslObjectWrapper(object):
         def __init__(self, obj, runner):
             self._runner = runner
-            if isinstance(obj, six.string_types):
-                self._object_id = obj
+            if isinstance(obj, (str,) + (dsl_types.MuranoType,)):
+                pass
             elif isinstance(obj, (object_model.Object, object_model.Ref)):
-                self._object_id = obj.id
+                obj = obj.id
             elif isinstance(obj, murano_object.MuranoObject):
-                self._object_id = obj.object_id
+                obj = obj.object_id
             else:
                 raise ValueError(
-                    'obj must be object ID string, MuranoObject or one of '
-                    'object_model helper classes (Object, Ref)')
+                    'obj must be object ID string, MuranoObject, MuranoType '
+                    'or one of object_model helper classes (Object, Ref)')
+            if isinstance(obj, str):
+                self._receiver = runner.executor.object_store.get(obj)
+            else:
+                self._receiver = obj
+
             self._preserve_exception = False
 
         def __getattr__(self, item):
             def call(*args, **kwargs):
                 return self._runner._execute(
-                    item, self._object_id, *args, **kwargs)
+                    item, self._receiver, *args, **kwargs)
             if item.startswith('test'):
                 return call
 
     def __init__(self, model, package_loader, functions):
-        if isinstance(model, six.string_types):
+        if isinstance(model, str):
             model = object_model.Object(model)
         model = object_model.build_model(model)
         if 'Objects' not in model:
@@ -78,10 +82,13 @@ class Runner(object):
         self.executor = executor.MuranoDslExecutor(
             package_loader, TestContextManager(functions),
             execution_session.ExecutionSession())
-        self._root = self.executor.load(model).object
+        self._root = self.executor.load(model)
+        if self._root:
+            self._root = self._root.object
+        if 'ObjectsCopy' in model:
+            self.executor.object_store.cleanup()
 
-    def _execute(self, name, object_id, *args, **kwargs):
-        obj = self.executor.object_store.get(object_id)
+    def _execute(self, name, obj, *args, **kwargs):
         try:
             final_args = []
             final_kwargs = {}
@@ -89,15 +96,16 @@ class Runner(object):
                 if isinstance(arg, object_model.Object):
                     arg = object_model.build_model(arg)
                 final_args.append(arg)
-            for name, arg in six.iteritems(kwargs):
+            for name, arg in kwargs.items():
                 if isinstance(arg, object_model.Object):
                     arg = object_model.build_model(arg)
                 final_kwargs[name] = arg
-            runtime_version = obj.type.package.runtime_version
+            cls = obj if isinstance(obj, dsl_types.MuranoType) else obj.type
+            runtime_version = cls.package.runtime_version
             yaql_engine = yaql_integration.choose_yaql_engine(runtime_version)
-            return dsl.to_mutable(obj.type.invoke(
-                name, self.executor, obj, tuple(final_args), final_kwargs),
-                yaql_engine)
+            with helpers.with_object_store(self.executor.object_store):
+                return dsl.to_mutable(cls.invoke(
+                    name, obj, tuple(final_args), final_kwargs), yaql_engine)
         except dsl_exception.MuranoPlException as e:
             if not self.preserve_exception:
                 original_exception = getattr(e, 'original_exception', None)
@@ -105,7 +113,7 @@ class Runner(object):
                         original_exception, dsl_exception.MuranoPlException):
                     exc_traceback = getattr(
                         e, 'original_traceback', None) or sys.exc_info()[2]
-                    six.reraise(
+                    utils.reraise(
                         type(original_exception),
                         original_exception,
                         exc_traceback)
@@ -118,13 +126,19 @@ class Runner(object):
     def on(self, obj):
         return Runner.DslObjectWrapper(obj, self)
 
+    def on_class(self, class_name):
+        cls = self.executor.package_loader.load_class_package(
+            class_name, helpers.parse_version_spec(None)).find_class(
+            class_name, False)
+        return Runner.DslObjectWrapper(cls, self)
+
     @property
     def root(self):
         return self._root
 
     @property
     def serialized_model(self):
-        return serializer.serialize_model(self._root, self.executor)[0]
+        return serializer.serialize_model(self._root, self.executor)
 
     @property
     def preserve_exception(self):
@@ -133,3 +147,6 @@ class Runner(object):
     @preserve_exception.setter
     def preserve_exception(self, value):
         self._preserve_exception = value
+
+    def session(self):
+        return helpers.with_object_store(self.executor.object_store)
