@@ -12,7 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
 from testtools import matchers
 
 from murano.dsl import serializer
@@ -26,19 +25,22 @@ from murano.tests.unit.dsl.foundation import test_case
 class TestResultsSerializer(test_case.DslTestCase):
     def setUp(self):
         super(TestResultsSerializer, self).setUp()
-        self._class2 = om.Object('SampleClass2', class2Property='string2')
+        self._class2 = om.Object('SampleClass2',
+                                 class2Property='string2')
         self._class1 = om.Object(
-            'SampleClass1',
+            'SampleClass1', 'def',
             stringProperty='string1',
             arbitraryProperty={'a': [1, 2]},
             classProperty=self._class2)
-        self._root_class = om.Object('ContractExamples',
+        self._root_class = om.Object('ContractExamples', 'abc',
                                      sampleClass=self._class1)
 
         self._runner = self.new_runner(self._root_class)
 
     def _test_data_in_section(self, name, serialized):
-        """Test that a section of Object Model has expected structure and
+        """Test that Model -> Load -> Serialize = Model
+
+        Test that a section of Object Model has expected structure and
            property values that are equal to those originally loaded
            (e.g. that Model -> Load -> Serialize = Model)
 
@@ -46,23 +48,22 @@ class TestResultsSerializer(test_case.DslTestCase):
            :param serialized: serialized Object Model
         """
 
-        self.assertEqual(self._root_class.id,
+        self.assertEqual('abc',
                          serialized[name]['?']['id'])
-        self.assertEqual('ContractExamples',
+        self.assertEqual('ContractExamples/0.0.0@tests',
                          serialized['Objects']['?']['type'])
         self.assertIsInstance(serialized[name]['sampleClass'], dict)
-        self.assertEqual(self._class1.id,
-                         serialized[name][
-                             'sampleClass']['?']['id'])
-        self.assertEqual('SampleClass1',
-                         serialized[name][
-                             'sampleClass']['?']['type'])
+        self.assertEqual('def',
+                         serialized[name]['sampleClass']['?']['id'])
+        self.assertEqual('SampleClass1/0.0.0@tests',
+                         serialized[name]['sampleClass']['?']['type'])
         self.assertEqual('string1',
-                         serialized[name][
-                             'sampleClass']['stringProperty'])
+                         serialized[name]['sampleClass']['stringProperty'])
 
     def test_results_serialize(self):
-        """Test that serialized Object Model has both Objects and ObjectsCopy
+        """Test that serialized contains same values and headers
+
+        Test that serialized Object Model has both Objects and ObjectsCopy
         sections and they both contain the same property values and object
         headers. Note, that Objects section may contain additional designer
         metadata and information on available actions that is not needed in
@@ -77,23 +78,41 @@ class TestResultsSerializer(test_case.DslTestCase):
         self._test_data_in_section('ObjectsCopy', serialized)
 
     def test_actions(self):
-        """Test that information on actions can be invoked on each MuranoPL
+        """Test that information on actions can be invoked
+
+        Test that information on actions can be invoked on each MuranoPL
         object are persisted into object header ('?' key) during serialization
         of Objects section of Object Model
 
         """
         serialized = self._runner.serialized_model
-        self.assertIsInstance(
-            serialized['Objects']['?'].get('_actions'), dict)
-        for action in serialized['Objects']['?']['_actions'].values():
+        actions = serialized['Objects']['?'].get('_actions')
+        self.assertIsInstance(actions, dict)
+        action_names = [action['name'] for action in actions.values()]
+        self.assertIn('testAction', action_names)
+        self.assertNotIn('notAction', action_names)
+        self.assertIn('testRootMethod', action_names)
+        action_meta = None
+        for action in actions.values():
             self.assertIsInstance(action.get('enabled'), bool)
-            self.assertIsInstance(action.get('name'), six.string_types)
+            self.assertIsInstance(action.get('name'), str)
             self.assertThat(
                 action['name'],
                 matchers.StartsWith('test'))
+            if action['name'] == 'testActionMeta':
+                action_meta = action
+            else:
+                self.assertEqual(action['title'], action['name'])
+        self.assertIsNotNone(action_meta)
+        self.assertEqual(action_meta['title'], "Title of the method")
+        self.assertEqual(action_meta['description'],
+                         "Description of the method")
+        self.assertEqual(action_meta['helpText'], "HelpText of the method")
 
     def test_attribute_serialization(self):
-        """Test that attributes produced by MuranoPL code are persisted in
+        """Test that attributes produced by MuranoPL code are persisted
+
+        Test that attributes produced by MuranoPL code are persisted in
         dedicated section of Object Model. Attributes are values that are
         stored in special key-value storage that is private to each class.
         Classes can store state data there. Attributes are persisted across
@@ -112,7 +131,9 @@ class TestResultsSerializer(test_case.DslTestCase):
             serialized['Attributes'][0])
 
     def test_attribute_deserialization(self):
-        """Test that attributes that are put into Attributes section of
+        """Test that attributes are available
+
+        Test that attributes that are put into Attributes section of
         Object Model become available to appropriate MuranoPL classes
         """
 
@@ -125,7 +146,9 @@ class TestResultsSerializer(test_case.DslTestCase):
             runner2.on(self._class1).testAttributes('John'))
 
     def test_value_deserialization(self):
-        """Test serialization of arbitrary values that can be returned
+        """Test serialization of arbitrary values
+
+        Test serialization of arbitrary values that can be returned
         from action methods
         """
 
@@ -140,4 +163,4 @@ class TestResultsSerializer(test_case.DslTestCase):
                 'key5': {'x': 'y'},
                 'key6': [{'w': 'q'}]
             },
-            serializer.serialize(result))
+            serializer.serialize(result, runner.executor))
